==> haskell-wizards-1.0.2-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wizards.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wizards
version: 1.0.2
id: wizards-1.0.2-7jdryUlVLPnLlRRmKn7qK0
key: wizards-1.0.2-7jdryUlVLPnLlRRmKn7qK0
license: BSD3
maintainer: liamoc@cse.unsw.edu.au
synopsis: High level, generic library for interrogative user interfaces
description:
    @wizards@ is a package designed for the quick and painless development of /interrogative/ programs, which
    revolve around a \"dialogue\" with the user, who is asked a series of questions in a sequence much like an
    installation wizard.
    .
    Everything from interactive system scripts, to installation wizards, to full-blown shells can be implemented with
    the support of @wizards@.
    .
    It is developed transparently on top of a free monad, which separates out the semantics of the program from any
    particular interface. A variety of backends exist, including console-based "System.Console.Wizard.Haskeline" and
    "System.Console.Wizard.BasicIO", and the pure "System.Console.Wizard.Pure". It is also possible to write your
    own backends, or extend existing back-ends with new features. While both built-in IO backends operate on a
    console, there is no reason why @wizards@ cannot also be used for making GUI wizard interfaces.
    .
    .
    See the github page for examples on usage:
    .
    <http://www.github.com/liamoc/wizards>
    .
    For creating backends, the module "System.Console.Wizard.Internal" has a brief tutorial.
category: User Interfaces
author: Liam O'\''Connor-Davis
exposed: True
indefinite: False
exposed-modules:
    System.Console.Wizard System.Console.Wizard.BasicIO
    System.Console.Wizard.Haskeline System.Console.Wizard.Internal
    System.Console.Wizard.Pure
abi: 33910d29b870b84adfaa6d6d01727211
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wizards-1.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/wizards-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/wizards-1.0.2
hs-libraries: HSwizards-1.0.2-7jdryUlVLPnLlRRmKn7qK0
depends:
    base-4.10.1.0 containers-0.5.10.2
    control-monad-free-0.6.1-EoxCTKmWueYB1zNGHjgrNE haskeline-0.7.4.0
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             control-monad-free-0.6.1-EoxCTKmWueYB1zNGHjgrNE=fa4ca909cba2e734b087390b5aa90cec
             haskeline-0.7.4.0=1141a9f24dba7d57fb2023df1fd20c51
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-wizards/html/wizards.haddock
haddock-html: /usr/share/doc/haskell-wizards/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wizards-1.0.2-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wizards.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wizards
version: 1.0.2
id: wizards-1.0.2-Dcq9i19xxqfPwQredUcWs
key: wizards-1.0.2-Dcq9i19xxqfPwQredUcWs
license: BSD3
maintainer: liamoc@cse.unsw.edu.au
synopsis: High level, generic library for interrogative user interfaces
description:
    @wizards@ is a package designed for the quick and painless development of /interrogative/ programs, which
    revolve around a \"dialogue\" with the user, who is asked a series of questions in a sequence much like an
    installation wizard.
    .
    Everything from interactive system scripts, to installation wizards, to full-blown shells can be implemented with
    the support of @wizards@.
    .
    It is developed transparently on top of a free monad, which separates out the semantics of the program from any
    particular interface. A variety of backends exist, including console-based "System.Console.Wizard.Haskeline" and
    "System.Console.Wizard.BasicIO", and the pure "System.Console.Wizard.Pure". It is also possible to write your
    own backends, or extend existing back-ends with new features. While both built-in IO backends operate on a
    console, there is no reason why @wizards@ cannot also be used for making GUI wizard interfaces.
    .
    .
    See the github page for examples on usage:
    .
    <http://www.github.com/liamoc/wizards>
    .
    For creating backends, the module "System.Console.Wizard.Internal" has a brief tutorial.
category: User Interfaces
author: Liam O'\''Connor-Davis
exposed: True
indefinite: False
exposed-modules:
    System.Console.Wizard System.Console.Wizard.BasicIO
    System.Console.Wizard.Haskeline System.Console.Wizard.Internal
    System.Console.Wizard.Pure
abi: 9c3b0773ab2955b4107b3c50b79eb807
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wizards-1.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/wizards-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/wizards-1.0.2
hs-libraries: HSwizards-1.0.2-Dcq9i19xxqfPwQredUcWs
depends:
    base-4.10.1.0 containers-0.5.10.2
    control-monad-free-0.6.1-EoxCTKmWueYB1zNGHjgrNE haskeline-0.7.4.0
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             control-monad-free-0.6.1-EoxCTKmWueYB1zNGHjgrNE=fa4ca909cba2e734b087390b5aa90cec
             haskeline-0.7.4.0=1141a9f24dba7d57fb2023df1fd20c51
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-wizards/html/wizards.haddock
haddock-html: /usr/share/doc/haskell-wizards/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
